svn commit: r1128865 [17/27] - in /ofbiz/branches/jackrabbit20100709: ./ applications/accounting/config/ applications/accounting/src/org/ofbiz/accounting/invoice/ applications/accounting/src/org/ofbiz/accounting/payment/ applications/accounting/src/org...

Previous Topic Next Topic
 
classic Classic list List threaded Threaded
1 message Options
Reply | Threaded
Open this post in threaded view
|

svn commit: r1128865 [17/27] - in /ofbiz/branches/jackrabbit20100709: ./ applications/accounting/config/ applications/accounting/src/org/ofbiz/accounting/invoice/ applications/accounting/src/org/ofbiz/accounting/payment/ applications/accounting/src/org...

sascharodekamp
Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.ui.tabs.min.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.ui.tabs.min.js?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.ui.tabs.min.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.ui.tabs.min.js Sun May 29 11:02:09 2011
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Tabs 1.8.11
+ * jQuery UI Tabs 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
@@ -31,5 +31,5 @@ if(a.hasClass("ui-tabs-selected")&&this.
 this._ui(this.anchors[b],this.panels[b]));return this}},disable:function(b){b=this._getIndex(b);var e=this.options;if(b!=e.selected){this.lis.eq(b).addClass("ui-state-disabled");e.disabled.push(b);e.disabled.sort();this._trigger("disable",null,this._ui(this.anchors[b],this.panels[b]))}return this},select:function(b){b=this._getIndex(b);if(b==-1)if(this.options.collapsible&&this.options.selected!=-1)b=this.options.selected;else return this;this.anchors.eq(b).trigger(this.options.event+".tabs");return this},
 load:function(b){b=this._getIndex(b);var e=this,a=this.options,c=this.anchors.eq(b)[0],h=d.data(c,"load.tabs");this.abort();if(!h||this.element.queue("tabs").length!==0&&d.data(c,"cache.tabs"))this.element.dequeue("tabs");else{this.lis.eq(b).addClass("ui-state-processing");if(a.spinner){var j=d("span",c);j.data("label.tabs",j.html()).html(a.spinner)}this.xhr=d.ajax(d.extend({},a.ajaxOptions,{url:h,success:function(k,n){e.element.find(e._sanitizeSelector(c.hash)).html(k);e._cleanup();a.cache&&d.data(c,
 "cache.tabs",true);e._trigger("load",null,e._ui(e.anchors[b],e.panels[b]));try{a.ajaxOptions.success(k,n)}catch(m){}},error:function(k,n){e._cleanup();e._trigger("load",null,e._ui(e.anchors[b],e.panels[b]));try{a.ajaxOptions.error(k,n,b,c)}catch(m){}}}));e.element.dequeue("tabs");return this}},abort:function(){this.element.queue([]);this.panels.stop(false,true);this.element.queue("tabs",this.element.queue("tabs").splice(-2,2));if(this.xhr){this.xhr.abort();delete this.xhr}this._cleanup();return this},
-url:function(b,e){this.anchors.eq(b).removeData("cache.tabs").data("load.tabs",e);return this},length:function(){return this.anchors.length}});d.extend(d.ui.tabs,{version:"1.8.11"});d.extend(d.ui.tabs.prototype,{rotation:null,rotate:function(b,e){var a=this,c=this.options,h=a._rotate||(a._rotate=function(j){clearTimeout(a.rotation);a.rotation=setTimeout(function(){var k=c.selected;a.select(++k<a.anchors.length?k:0)},b);j&&j.stopPropagation()});e=a._unrotate||(a._unrotate=!e?function(j){j.clientX&&
+url:function(b,e){this.anchors.eq(b).removeData("cache.tabs").data("load.tabs",e);return this},length:function(){return this.anchors.length}});d.extend(d.ui.tabs,{version:"1.8.13"});d.extend(d.ui.tabs.prototype,{rotation:null,rotate:function(b,e){var a=this,c=this.options,h=a._rotate||(a._rotate=function(j){clearTimeout(a.rotation);a.rotation=setTimeout(function(){var k=c.selected;a.select(++k<a.anchors.length?k:0)},b);j&&j.stopPropagation()});e=a._unrotate||(a._unrotate=!e?function(j){j.clientX&&
 a.rotate(null)}:function(){t=c.selected;h()});if(b){this.element.bind("tabsshow",h);this.anchors.bind(c.event+".tabs",e);h()}else{clearTimeout(a.rotation);this.element.unbind("tabsshow",h);this.anchors.unbind(c.event+".tabs",e);delete this._rotate;delete this._unrotate}return this}})})(jQuery);

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.ui.widget.min.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.ui.widget.min.js?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.ui.widget.min.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.ui.widget.min.js Sun May 29 11:02:09 2011
@@ -1,5 +1,5 @@
 /*!
- * jQuery UI Widget 1.8.11
+ * jQuery UI Widget 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/version.txt
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/version.txt?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/version.txt (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/version.txt Sun May 29 11:02:09 2011
@@ -1 +1 @@
-1.8.11
+1.8.13

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/index.html
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/index.html?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/index.html (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/index.html Sun May 29 11:02:09 2011
@@ -3,9 +3,9 @@
  <head>
  <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1" />
  <title>jQuery UI Example Page</title>
- <link type="text/css" href="css/ui-lightness/jquery-ui-1.8.11.custom.css" rel="stylesheet" />
+ <link type="text/css" href="css/ui-lightness/jquery-ui-1.8.13.custom.css" rel="stylesheet" />
  <script type="text/javascript" src="js/jquery-1.5.1.min.js"></script>
- <script type="text/javascript" src="js/jquery-ui-1.8.11.custom.min.js"></script>
+ <script type="text/javascript" src="js/jquery-ui-1.8.13.custom.min.js"></script>
  <script type="text/javascript">
  $(function(){
 
@@ -73,7 +73,7 @@
  </head>
  <body>
  <h1>Welcome to jQuery UI!</h1>
- <p style="font-size: 1.3em; line-height: 1.5; margin: 1em 0; width: 50%;">This page demonstrates the widgets you downloaded using the theme you selected in the download builder. We've included and linked to minified versions of <a href="js/jquery-1.5.1.min.js">jQuery</a>, your personalized copy of <a href="js/jquery-ui-1.8.11.custom.min.js">jQuery UI (js/jquery-ui-1.8.11.custom.min.js)</a>, and <a href="css/ui-lightness/jquery-ui-1.8.11.custom.css">css/ui-lightness/jquery-ui-1.8.11.custom.css</a> which imports the entire jQuery UI CSS Framework. You can choose to link a subset of the CSS Framework depending on your needs. </p>
+ <p style="font-size: 1.3em; line-height: 1.5; margin: 1em 0; width: 50%;">This page demonstrates the widgets you downloaded using the theme you selected in the download builder. We've included and linked to minified versions of <a href="js/jquery-1.5.1.min.js">jQuery</a>, your personalized copy of <a href="js/jquery-ui-1.8.13.custom.min.js">jQuery UI (js/jquery-ui-1.8.13.custom.min.js)</a>, and <a href="css/ui-lightness/jquery-ui-1.8.13.custom.css">css/ui-lightness/jquery-ui-1.8.13.custom.css</a> which imports the entire jQuery UI CSS Framework. You can choose to link a subset of the CSS Framework depending on your needs. </p>
  <p style="font-size: 1.2em; line-height: 1.5; margin: 1em 0; width: 50%;">You've downloaded components and a theme that are compatible with jQuery 1.3+. Please make sure you are using jQuery 1.3+ in your production environment.</p>
 
  <p style="font-weight: bold; margin: 2em 0 1em; font-size: 1.3em;">YOUR COMPONENTS:</p>

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/myportal.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/myportal.js?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/myportal.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/myportal.js Sun May 29 11:02:09 2011
@@ -20,6 +20,7 @@
 //Drag & Drop Functions for myPortal
 
 //global Var for controlling hover Boxes
+"use strict";
 var SORTABLE_COLUMN_LIST = null;
 var IS_UPDATED = false;
 var DESTINATION_COLUMN_ID = null;
@@ -27,8 +28,9 @@ var DESTINATION_COLUMN_ID = null;
 //init KeyListener
 jQuery(document).ready( function() {
     // initializ the d_n_d jQuery functions
-    jQuery("" + SORTABLE_COLUMN_LIST + "").sortable({
+    jQuery(SORTABLE_COLUMN_LIST).sortable({
         connectWith: ".connectedSortable",
+        handle: ".portlet-config, .screenlet-title-bar",
         tolerance: "pointer",
         dropOnEmpty: true,
         cursor: "move",
@@ -40,13 +42,12 @@ jQuery(document).ready( function() {
                     DESTINATION_COLUMN_ID = jQuery(this).attr("id");
                 },
         stop: function(event, ui) {
-                    preparePortletBackgroundOrderChange(jQuery("" + SORTABLE_COLUMN_LIST+ "").sortable("toArray", {connected: true}), jQuery(ui.item).attr("id"), DESTINATION_COLUMN_ID);
+                    preparePortletBackgroundOrderChange(jQuery(SORTABLE_COLUMN_LIST).sortable("toArray", {connected: true}), jQuery(ui.item).attr("id"), DESTINATION_COLUMN_ID);
                     // reset the flags
                     IS_UPDATED = false;
                     DESTINATION_COLUMN_ID = null;
                 }
-    }).disableSelection();
-    
+    });
 });
 
 function preparePortletBackgroundOrderChange(serializedDate, dragedItemId, destinationColumnId) {
@@ -150,11 +151,8 @@ function updatePortletOrder(currentItem,
         url: "/myportal/control/updatePortalPagePortletSeqAjax",
         data: requestData,
         type: "POST",
-        success: function(data){
-            onCompleteRequest();
-        }
-    });
-    
+    }).success( function(data){ onCompleteRequest(); });
+
 }
 
 //removes the loading image

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/selectall.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/selectall.js?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/selectall.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/selectall.js Sun May 29 11:02:09 2011
@@ -389,7 +389,7 @@ function ajaxSubmitFormUpdateAreas(form,
  * form of: areaId, target, target parameters [, areaId, target, target parameters...].
 */
 
-function ajaxAutoCompleter(areaCsvString, showDescription, defaultMinLength, formName){
+function ajaxAutoCompleter(areaCsvString, showDescription, defaultMinLength, defaultDelay, formName){
     var areaArray = areaCsvString.replace(/&amp;/g, '&').split(",");
     var numAreas = parseInt(areaArray.length / 3);
     
@@ -403,6 +403,7 @@ function ajaxAutoCompleter(areaCsvString
         
         jQuery("#" + div).autocomplete({
             minLength: defaultMinLength,
+            delay: defaultDelay,
             source: function(request, response){
                 jQuery.ajax({
                     url: url,
@@ -603,19 +604,19 @@ function toggleCollapsiblePanel(link, ar
 */
 function toggleScreenlet(link, areaId, saveCollapsed, expandTxt, collapseTxt){
    toggleCollapsiblePanel(link, areaId, expandTxt, collapseTxt);
-   var container = jQuery("#" + areaId);
-   var screenlet = jQuery(link).parents('div:first');;
-   if(container.is(':visible')){
-       var currentParam = screenlet.id + "_collapsed=false";
-       var newParam = screenlet.id + "_collapsed=true";
+   var screenlet = jQuery(link).parents('div:eq(1)').attr('id');
+   var title = jQuery(link).attr('title');
+   if(title == expandTxt){
+       var currentParam = screenlet + "_collapsed=false";
+       var newParam = screenlet + "_collapsed=true";
        if(saveCollapsed=='true'){
-           setUserLayoutPreferences('GLOBAL_PREFERENCES',screenlet.id+"_collapsed",'true');
+           setUserLayoutPreferences('GLOBAL_PREFERENCES',screenlet+"_collapsed",'true');
        }
    } else {
-       var currentParam = screenlet.id + "_collapsed=true";
-       var newParam = screenlet.id + "_collapsed=false";
+       var currentParam = screenlet + "_collapsed=true";
+       var newParam = screenlet + "_collapsed=false";
        if(saveCollapsed=='true'){
-           setUserLayoutPreferences('GLOBAL_PREFERENCES',screenlet.id+"_collapsed",'false');
+           setUserLayoutPreferences('GLOBAL_PREFERENCES',screenlet+"_collapsed",'false');
        }
    }
    var paginationMenus = jQuery('div.nav-pager');

Propchange: ofbiz/branches/jackrabbit20100709/framework/security/data/PasswordSecurityData.xml
------------------------------------------------------------------------------
--- svn:mergeinfo (original)
+++ svn:mergeinfo Sun May 29 11:02:09 2011
@@ -2,4 +2,4 @@
 /ofbiz/branches/dojo1.4/applications/securityext/data/PasswordSecurityData.xml:951708-952957
 /ofbiz/branches/jquery/applications/securityext/data/PasswordSecurityData.xml:952958-1044489
 /ofbiz/branches/multitenant20100310/applications/securityext/data/PasswordSecurityData.xml:921280-927264
-/ofbiz/trunk/framework/security/data/PasswordSecurityData.xml:962442-1096699
+/ofbiz/trunk/framework/security/data/PasswordSecurityData.xml:962442-1128853

Modified: ofbiz/branches/jackrabbit20100709/framework/security/entitydef/entitymodel.xml
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/security/entitydef/entitymodel.xml?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/security/entitydef/entitymodel.xml (original)
+++ ofbiz/branches/jackrabbit20100709/framework/security/entitydef/entitymodel.xml Sun May 29 11:02:09 2011
@@ -225,7 +225,6 @@ under the License.
     </entity>
     <view-entity entity-name="UserLoginAndProtectedView"
           package-name="org.ofbiz.security.securitygroup"
-          never-cache="true"
           title="UserLogin And ProtectedView View Entity">
       <member-entity entity-alias="ULSGPV" entity-name="UserLoginSecurityGroup"/>
       <member-entity entity-alias="PV" entity-name="ProtectedView"/>

Modified: ofbiz/branches/jackrabbit20100709/framework/security/src/org/ofbiz/security/authz/AbstractAuthorization.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/security/src/org/ofbiz/security/authz/AbstractAuthorization.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/security/src/org/ofbiz/security/authz/AbstractAuthorization.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/security/src/org/ofbiz/security/authz/AbstractAuthorization.java Sun May 29 11:02:09 2011
@@ -83,7 +83,7 @@ public abstract class AbstractAuthorizat
      *
      * @param userId the user's userId
      * @param permissionRegexp permission string containing regexp in the base position
-     * @param expanded  true if the permission string is already expanded, false if it will contain ${} context values
+     * @param context the context
      * @return a map of allowed or disallowed permissions
      */
     public Map<String, Boolean> findMatchingPermission(String userId, String permissionRegexp, Map<String, ? extends Object> context) {

Modified: ofbiz/branches/jackrabbit20100709/framework/service/servicedef/services.xml
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/service/servicedef/services.xml?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/service/servicedef/services.xml (original)
+++ ofbiz/branches/jackrabbit20100709/framework/service/servicedef/services.xml Sun May 29 11:02:09 2011
@@ -42,6 +42,7 @@ under the License.
         </required-permissions>
         <auto-attributes entity-name="JobSandbox" include="pk" mode="IN" optional="false"/>
         <attribute name="cancelDateTime" type="Timestamp" mode="OUT" optional="false"/>
+        <attribute name="statusId" type="String" mode="OUT" optional="false"/> <!-- To more easily see current pending jobs and possibly cancel some others -->
     </service>
 
     <service name="cancelJobRetries" engine="java"

Modified: ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/GenericAbstractDispatcher.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/GenericAbstractDispatcher.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/GenericAbstractDispatcher.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/GenericAbstractDispatcher.java Sun May 29 11:02:09 2011
@@ -117,9 +117,6 @@ public abstract class GenericAbstractDis
         schedule(jobName, poolName, serviceName, ServiceUtil.makeContext(context), startTime, frequency, interval, count, endTime, maxRetry);
     }
 
-    /**
-     * @see org.ofbiz.service.LocalDispatcher#setRollbackService(java.lang.String, java.util.Map, boolean)
-     */
     public void addRollbackService(String serviceName, Map<String, ? extends Object> context, boolean persist) throws GenericServiceException {
         ServiceXaWrapper xa = new ServiceXaWrapper(this.getDispatchContext());
         xa.setRollbackService(serviceName, context, true, persist);
@@ -135,9 +132,6 @@ public abstract class GenericAbstractDis
         addRollbackService(serviceName, ServiceUtil.makeContext(context), persist);
     }
 
-    /**
-     * @see org.ofbiz.service.LocalDispatcher#setCommitService(java.lang.String, java.util.Map, boolean)
-     */
     public void addCommitService(String serviceName, Map<String, ? extends Object> context, boolean persist) throws GenericServiceException {
         ServiceXaWrapper xa = new ServiceXaWrapper(this.getDispatchContext());
         xa.setCommitService(serviceName, context, true, persist);

Modified: ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/GenericInvoker.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/GenericInvoker.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/GenericInvoker.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/GenericInvoker.java Sun May 29 11:02:09 2011
@@ -67,7 +67,7 @@ public interface GenericInvoker extends
      * Send the service callbacks
      * @param engine GenericEngine object
      * @param context Map of name, value pairs composing the context
-     * @param cbObj Object to return to callback (Throwable or Map)
+     * @param result Object to return to callback (Throwable or Map)
      * @param mode Service mode (sync or async)
      * @throws GenericServiceException
      */

Modified: ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/LocalDispatcher.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/LocalDispatcher.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/LocalDispatcher.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/LocalDispatcher.java Sun May 29 11:02:09 2011
@@ -45,7 +45,7 @@ public interface LocalDispatcher {
 
     /**
      * Returns whether Service Engine Condition Actions (SECAs) are disabled or not.
-     * @return
+     * @return returns whether Service Engine Condition Actions (SECAs) are disabled or not.
      * @throws GenericServiceException
      */
     public boolean isEcasDisabled();

Modified: ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/ModelService.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/ModelService.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/ModelService.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/ModelService.java Sun May 29 11:02:09 2011
@@ -475,8 +475,9 @@ public class ModelService extends Abstra
 
     /**
      * Validates a Map against the IN or OUT parameter information
-     * @param test The Map object to test
+     * @param context the context
      * @param mode Test either mode IN or mode OUT
+     * @param locale the actual locale to use
      */
     public void validate(Map<String, Object> context, String mode, Locale locale) throws ServiceValidationException {
         Map<String, String> requiredInfo = FastMap.newInstance();
@@ -833,7 +834,8 @@ public class ModelService extends Abstra
      * @param source The source map
      * @param mode The mode which to build the new map
      * @param includeInternal When false will exclude internal fields
-     * @param tz TimeZone to use to do some type conversion
+     * @param errorMessages the list of error messages
+     * @param timeZone TimeZone to use to do some type conversion
      * @param locale Locale to use to do some type conversion
      */
     public Map<String, Object> makeValid(Map<String, ? extends Object> source, String mode, boolean includeInternal, List<Object> errorMessages, TimeZone timeZone, Locale locale) {

Modified: ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/ServiceDispatcher.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/ServiceDispatcher.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/ServiceDispatcher.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/ServiceDispatcher.java Sun May 29 11:02:09 2011
@@ -243,7 +243,7 @@ public class ServiceDispatcher {
      * Run the service synchronously and return the result.
      * @param localName Name of the context to use.
      * @param modelService Service model object.
-     * @param context Map of name, value pairs composing the context.
+     * @param params Map of name, value pairs composing the parameters.
      * @param validateOut Validate OUT parameters
      * @return Map of name, value pairs composing the result.
      * @throws ServiceAuthException
@@ -618,7 +618,7 @@ public class ServiceDispatcher {
      * Run the service asynchronously, passing an instance of GenericRequester that will receive the result.
      * @param localName Name of the context to use.
      * @param service Service model object.
-     * @param context Map of name, value pairs composing the context.
+     * @param params Map of name, value pairs composing the parameters.
      * @param requester Object implementing GenericRequester interface which will receive the result.
      * @param persist True for store/run; False for run.
      * @throws ServiceAuthException

Modified: ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/ServiceUtil.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/ServiceUtil.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/ServiceUtil.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/ServiceUtil.java Sun May 29 11:02:09 2011
@@ -543,6 +543,7 @@ public class ServiceUtil {
         if (cancelDate != null) {
             Map<String, Object> result = ServiceUtil.returnSuccess();
             result.put("cancelDateTime", cancelDate);
+            result.put("statusId", "SERVICE_PENDING"); // To more easily see current pending jobs and possibly cancel some others
             return result;
         } else {
             String errMsg = UtilProperties.getMessage(ServiceUtil.resource, "serviceUtil.unable_to_cancel_job", locale) + " : " + job;

Modified: ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/calendar/ExpressionUiHelper.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/calendar/ExpressionUiHelper.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/calendar/ExpressionUiHelper.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/calendar/ExpressionUiHelper.java Sun May 29 11:02:09 2011
@@ -42,7 +42,7 @@ public class ExpressionUiHelper {
     public static final int Occurrence[] = {1, 2, 3, 4, 5, -1, -2, -3, -4 -5};
 
     /** Returns a List of valid DayInMonth occurrence int values.
-     * @return
+     * @return returns a List of valid DayInMonth occurrence int values
      */
     public static List<?> getOccurrenceList() {
         return Arrays.asList(Occurrence);

Modified: ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/calendar/TemporalExpressions.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/calendar/TemporalExpressions.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/calendar/TemporalExpressions.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/calendar/TemporalExpressions.java Sun May 29 11:02:09 2011
@@ -988,7 +988,7 @@ public class TemporalExpressions impleme
         protected final int start;
 
         /**
-         * @param hour An integer in the range of 0 to 59.
+         * @param minute An integer in the range of 0 to 59.
          */
         public MinuteRange(int minute) {
             this(minute, minute);

Modified: ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/engine/AbstractEngine.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/engine/AbstractEngine.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/engine/AbstractEngine.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/engine/AbstractEngine.java Sun May 29 11:02:09 2011
@@ -84,7 +84,7 @@ public abstract class AbstractEngine imp
     }
 
     /**
-     * @see org.ofbiz.service.engine.GenericEngine#sendCallbacks(org.ofbiz.service.ModelService, java.util.Map, java.lang.Object, int)
+     * @see org.ofbiz.service.engine.GenericEngine#sendCallbacks(org.ofbiz.service.ModelService, java.util.Map, int)
      */
     public void sendCallbacks(ModelService model, Map<String, Object> context, int mode) throws GenericServiceException {
         if (!allowCallbacks(model, context, mode)) return;

Modified: ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/engine/GenericEngine.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/engine/GenericEngine.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/engine/GenericEngine.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/engine/GenericEngine.java Sun May 29 11:02:09 2011
@@ -81,7 +81,6 @@ public interface GenericEngine {
      * Send the service callbacks
      * @param modelService Service model object
      * @param context Map of name, value pairs composing the context
-     * @param cbObj Object to return to callback (Throwable or Map)
      * @param mode Service mode (sync or async)
      * @throws GenericServiceException
      */

Modified: ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/jms/AbstractJmsListener.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/jms/AbstractJmsListener.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/jms/AbstractJmsListener.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/jms/AbstractJmsListener.java Sun May 29 11:02:09 2011
@@ -47,7 +47,7 @@ public abstract class AbstractJmsListene
 
     /**
      * Initializes the LocalDispatcher for this service listener.
-     * @param dispatcher
+     * @param serviceDispatcher the service dispatcher
      */
     protected AbstractJmsListener(ServiceDispatcher serviceDispatcher) {
         this.dispatcher = GenericDispatcher.getLocalDispatcher("entity-default", null, null, this.getClass().getClassLoader(), serviceDispatcher);

Modified: ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/test/ServiceEngineTestServices.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/test/ServiceEngineTestServices.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/test/ServiceEngineTestServices.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/service/src/org/ofbiz/service/test/ServiceEngineTestServices.java Sun May 29 11:02:09 2011
@@ -228,9 +228,9 @@ public class ServiceEngineTestServices {
      * current service run is complete, and AFTER it has committed or rolled back its transaction; if a service finds
      * it has a lock wait timeout, add itself to the list for its parent service (somehow...) and off we go!
      *
-     * @param dctx
-     * @param context
-     * @return
+     * @param dctx the dispatch context
+     * @param context the context
+     * @return returns the results of the service execution
      */
     public static Map<String, Object> testServiceLockWaitTimeoutRetryCantRecover(DispatchContext dctx, Map<String, ? extends Object> context) {
         Delegator delegator = dctx.getDelegator();

Modified: ofbiz/branches/jackrabbit20100709/framework/testtools/src/org/ofbiz/testtools/EntityXmlAssertTest.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/testtools/src/org/ofbiz/testtools/EntityXmlAssertTest.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/testtools/src/org/ofbiz/testtools/EntityXmlAssertTest.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/testtools/src/org/ofbiz/testtools/EntityXmlAssertTest.java Sun May 29 11:02:09 2011
@@ -42,7 +42,9 @@ public class EntityXmlAssertTest extends
     protected String action;
 
     /**
-     * @param modelTestSuite
+     * Tests of entity xml
+     * @param caseName test case name
+     * @param mainElement DOM main element
      */
     public EntityXmlAssertTest(String caseName, Element mainElement) {
         super(caseName);

Modified: ofbiz/branches/jackrabbit20100709/framework/testtools/src/org/ofbiz/testtools/JythonTest.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/testtools/src/org/ofbiz/testtools/JythonTest.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/testtools/src/org/ofbiz/testtools/JythonTest.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/testtools/src/org/ofbiz/testtools/JythonTest.java Sun May 29 11:02:09 2011
@@ -30,7 +30,9 @@ public class JythonTest extends OFBizTes
     protected String scriptLocation;
 
     /**
-     * @param modelTestSuite
+     * Tests of Jython
+     * @param caseName test case name
+     * @param mainElement DOM main element
      */
     public JythonTest(String caseName, Element mainElement) {
         super(caseName);

Modified: ofbiz/branches/jackrabbit20100709/framework/testtools/src/org/ofbiz/testtools/ModelTestSuite.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/testtools/src/org/ofbiz/testtools/ModelTestSuite.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/testtools/src/org/ofbiz/testtools/ModelTestSuite.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/testtools/src/org/ofbiz/testtools/ModelTestSuite.java Sun May 29 11:02:09 2011
@@ -23,6 +23,7 @@ import java.util.List;
 
 import javolution.util.FastList;
 import junit.framework.Test;
+import junit.framework.TestCase;
 import junit.framework.TestSuite;
 
 import org.apache.commons.lang.RandomStringUtils;
@@ -95,7 +96,8 @@ public class ModelTestSuite {
             String className = testElement.getAttribute("class-name");
 
             try {
-                Class<?> clz = ObjectType.loadClass(className);
+                @SuppressWarnings("unchecked")
+                Class<? extends TestCase> clz = (Class<? extends TestCase>) ObjectType.loadClass(className);
                 TestSuite suite = new TestSuite();
                 suite.addTestSuite(clz);
                 Enumeration<?> testEnum = suite.tests();

Modified: ofbiz/branches/jackrabbit20100709/framework/testtools/src/org/ofbiz/testtools/ServiceTest.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/testtools/src/org/ofbiz/testtools/ServiceTest.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/testtools/src/org/ofbiz/testtools/ServiceTest.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/testtools/src/org/ofbiz/testtools/ServiceTest.java Sun May 29 11:02:09 2011
@@ -39,7 +39,9 @@ public class ServiceTest extends OFBizTe
     protected String serviceName;
 
     /**
-     * @param modelTestSuite
+     * Tests of Service
+     * @param caseName test case name
+     * @param mainElement DOM main element
      */
     public ServiceTest(String caseName, Element mainElement) {
         super(caseName);

Modified: ofbiz/branches/jackrabbit20100709/framework/testtools/src/org/ofbiz/testtools/SimpleMethodTest.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/testtools/src/org/ofbiz/testtools/SimpleMethodTest.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/testtools/src/org/ofbiz/testtools/SimpleMethodTest.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/testtools/src/org/ofbiz/testtools/SimpleMethodTest.java Sun May 29 11:02:09 2011
@@ -42,7 +42,9 @@ public class SimpleMethodTest extends OF
     protected String methodName;
 
     /**
-     * @param modelTestSuite
+     * Tests of Simple Method
+     * @param caseName test case name
+     * @param mainElement DOM main element
      */
     public SimpleMethodTest(String caseName, Element mainElement) {
         this(caseName, mainElement.getAttribute("location"), mainElement.getAttribute("name"));

Modified: ofbiz/branches/jackrabbit20100709/framework/testtools/src/org/ofbiz/testtools/selenium/SeleniumHtml.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/testtools/src/org/ofbiz/testtools/selenium/SeleniumHtml.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/testtools/src/org/ofbiz/testtools/selenium/SeleniumHtml.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/testtools/src/org/ofbiz/testtools/selenium/SeleniumHtml.java Sun May 29 11:02:09 2011
@@ -98,7 +98,7 @@ public class SeleniumHtml {
     }
 
     public static String runHtmlTestSuite(HttpServletRequest request, HttpServletResponse response) throws Exception {
-        Map parameters = UtilHttp.getParameterMap(request);
+        Map<String, Object> parameters = UtilHttp.getParameterMap(request);
         String para = (String) parameters.get("testSuitePath");
 
         try {
@@ -118,7 +118,7 @@ public class SeleniumHtml {
             if (testFile.exists()) {
                 if (Debug.infoOn()) Debug.logInfo("Running this testsuite: " + testFile.getAbsolutePath(), module);
 
-                Map results = client.runSuite(testFile.getAbsolutePath());
+                Map<String, Object> results = client.runSuite(testFile.getAbsolutePath());
                 if ("true".equals(results.get("status").toString())) {
                     request.setAttribute("_EVENT_MESSAGE_LIST_", results.get("logs"));
                 } else {
@@ -132,7 +132,7 @@ public class SeleniumHtml {
         return "success";
    }
 
-    public Map runSuite(String filename) throws Exception {
+    public Map<String, Object> runSuite(String filename) throws Exception {
         TestSuite suite = new TestSuite();
         suite.file = new File(filename);
         File suiteDirectory = suite.file.getParentFile();
@@ -146,7 +146,7 @@ public class SeleniumHtml {
 
         Map<String, Object> results = FastMap.newInstance();
         List<String> messages = FastList.newInstance();
-        Map testResults;
+        Map<String, Object> testResults;
 
         for (int i = 1; i < tableRows.getLength(); i++) {
             Element tableRow = (Element) tableRows.item(i);
@@ -172,7 +172,7 @@ public class SeleniumHtml {
         return results;
     }
 
-    public Map runTest(Test test) throws Exception {
+    public Map<String, Object> runTest(Test test) throws Exception {
         String filename = test.file.toString();
         List<String> messages = FastList.newInstance();
 
@@ -297,7 +297,7 @@ public class SeleniumHtml {
             Debug.logInfo("XML detected; using default XML parser.", module);
         } else {
             try {
-                Class nekoParserClass = Class.forName("org.cyberneko.html.parsers.DOMParser");
+                Class<?> nekoParserClass = Class.forName("org.cyberneko.html.parsers.DOMParser");
                 Object parser = nekoParserClass.newInstance();
                 Method parse = nekoParserClass.getMethod("parse", new Class[] { String.class });
                 Method getDocument = nekoParserClass.getMethod("getDocument", new Class[0]);

Modified: ofbiz/branches/jackrabbit20100709/framework/testtools/src/org/ofbiz/testtools/seleniumxml/SeleniumXml.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/testtools/src/org/ofbiz/testtools/seleniumxml/SeleniumXml.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/testtools/src/org/ofbiz/testtools/seleniumxml/SeleniumXml.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/testtools/src/org/ofbiz/testtools/seleniumxml/SeleniumXml.java Sun May 29 11:02:09 2011
@@ -187,7 +187,7 @@ public class SeleniumXml {
     /**
      * Constructor to preset with an existing Map of parameters.  Intended to be used
      * for nested Selenium tests.
-     * @param map
+     * @param selenium the SeleniumXml Object
      */
     public SeleniumXml(SeleniumXml selenium) {
         this.sel = selenium.getSelenium();

Modified: ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/control/ContextFilter.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/control/ContextFilter.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/control/ContextFilter.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/control/ContextFilter.java Sun May 29 11:02:09 2011
@@ -44,7 +44,6 @@ import javolution.util.FastList;
 import org.ofbiz.base.container.Container;
 import org.ofbiz.base.container.ContainerException;
 import org.ofbiz.base.container.ContainerLoader;
-import org.ofbiz.base.start.StartupException;
 import org.ofbiz.base.util.CachedClassLoader;
 import org.ofbiz.base.util.Debug;
 import org.ofbiz.base.util.StringUtil;

Modified: ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/control/RequestHandler.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/control/RequestHandler.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/control/RequestHandler.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/control/RequestHandler.java Sun May 29 11:02:09 2011
@@ -355,7 +355,12 @@ public class RequestHandler {
             if (!"success".equalsIgnoreCase(checkLoginReturnString)) {
                 // previous URL already saved by event, so just do as the return says...
                 eventReturn = checkLoginReturnString;
-                requestMap = requestMapMap.get("checkLogin");
+                // if the request is an ajax request we don't want to return the default login check
+                if (!"XMLHttpRequest".equals(request.getHeader("X-Requested-With"))) {
+                    requestMap = requestMapMap.get("checkLogin");
+                } else {
+                    requestMap = requestMapMap.get("ajaxCheckLogin");
+                }
             }
         }
 
@@ -902,10 +907,9 @@ public class RequestHandler {
     /**
      * Creates a query string based on the redirect parameters for a request response, if specified, or for all request parameters if no redirect parameters are specified.
      *
-     * @param request
-     * @param requestUri
-     * @param eventReturnString
-     * @return
+     * @param request the Http request
+     * @param requestResponse the RequestResponse Object
+     * @return return the query string
      */
     public String makeQueryString(HttpServletRequest request, ConfigXMLReader.RequestResponse requestResponse) {
         if (requestResponse == null ||

Modified: ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/BsfEventHandler.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/BsfEventHandler.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/BsfEventHandler.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/BsfEventHandler.java Sun May 29 11:02:09 2011
@@ -52,7 +52,7 @@ public class BsfEventHandler implements
     }
 
     /**
-     * @see org.ofbiz.webapp.event.EventHandler#invoke(java.lang.String, java.lang.String, javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse)
+     * @see org.ofbiz.webapp.event.EventHandler#invoke(ConfigXMLReader.Event, ConfigXMLReader.RequestMap, javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse)
      */
     public String invoke(ConfigXMLReader.Event event, ConfigXMLReader.RequestMap requestMap, HttpServletRequest request, HttpServletResponse response) throws EventHandlerException {
         ServletContext context = (ServletContext) request.getAttribute("servletContext");

Modified: ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/JavaEventHandler.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/JavaEventHandler.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/JavaEventHandler.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/JavaEventHandler.java Sun May 29 11:02:09 2011
@@ -28,6 +28,7 @@ import javax.servlet.http.HttpServletRes
 import javolution.util.FastMap;
 
 import org.ofbiz.base.util.Debug;
+import org.ofbiz.webapp.control.ConfigXMLReader;
 import org.ofbiz.webapp.control.ConfigXMLReader.Event;
 import org.ofbiz.webapp.control.ConfigXMLReader.RequestMap;
 
@@ -47,7 +48,7 @@ public class JavaEventHandler implements
     }
 
     /**
-     * @see org.ofbiz.webapp.event.EventHandler#invoke(Event, org.ofbiz.webapp.control.ConfigXMLReader.RequestMap, HttpServletRequest, HttpServletResponse)
+     * @see org.ofbiz.webapp.event.EventHandler#invoke(ConfigXMLReader.Event, ConfigXMLReader.RequestMap, javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse)
      */
     public String invoke(Event event, RequestMap requestMap, HttpServletRequest request, HttpServletResponse response) throws EventHandlerException {
         Class<?> eventClass = this.eventClassMap.get(event.path);

Modified: ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/RomeEventHandler.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/RomeEventHandler.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/RomeEventHandler.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/RomeEventHandler.java Sun May 29 11:02:09 2011
@@ -25,6 +25,7 @@ import javax.servlet.ServletContext;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
+import org.ofbiz.webapp.control.ConfigXMLReader;
 import org.ofbiz.webapp.control.RequestHandler;
 import org.ofbiz.webapp.control.ConfigXMLReader.Event;
 import org.ofbiz.webapp.control.ConfigXMLReader.RequestMap;
@@ -61,7 +62,7 @@ public class RomeEventHandler implements
     }
 
     /**
-     * @see org.ofbiz.webapp.event.EventHandler#invoke(Event, org.ofbiz.webapp.control.ConfigXMLReader.RequestMap, HttpServletRequest, HttpServletResponse)
+     * @see org.ofbiz.webapp.event.EventHandler#invoke(ConfigXMLReader.Event, ConfigXMLReader.RequestMap, javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse)
      */
     public String invoke(Event event, RequestMap requestMap, HttpServletRequest request, HttpServletResponse response) throws EventHandlerException {
         // generate the main and entry links

Modified: ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/SOAPEventHandler.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/SOAPEventHandler.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/SOAPEventHandler.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/SOAPEventHandler.java Sun May 29 11:02:09 2011
@@ -56,6 +56,7 @@ import org.ofbiz.service.ServiceUtil;
 import org.ofbiz.service.engine.SoapSerializer;
 import org.ofbiz.webapp.control.ConfigXMLReader.Event;
 import org.ofbiz.webapp.control.ConfigXMLReader.RequestMap;
+import org.ofbiz.webapp.control.ConfigXMLReader;
 import org.ofbiz.webapp.control.RequestHandler;
 import org.w3c.dom.Document;
 
@@ -73,7 +74,7 @@ public class SOAPEventHandler implements
     }
 
     /**
-     * @see org.ofbiz.webapp.event.EventHandler#invoke(Event, org.ofbiz.webapp.control.ConfigXMLReader.RequestMap, HttpServletRequest, HttpServletResponse)
+     * @see org.ofbiz.webapp.event.EventHandler#invoke(ConfigXMLReader.Event, ConfigXMLReader.RequestMap, javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse)
      */
     public String invoke(Event event, RequestMap requestMap, HttpServletRequest request, HttpServletResponse response) throws EventHandlerException {
         LocalDispatcher dispatcher = (LocalDispatcher) request.getAttribute("dispatcher");

Modified: ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/ServiceEventHandler.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/ServiceEventHandler.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/ServiceMultiEventHandler.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/ServiceMultiEventHandler.java Sun May 29 11:02:09 2011
@@ -74,7 +74,7 @@ public class ServiceMultiEventHandler im
     }
 
     /**
-     * @see org.ofbiz.webapp.event.EventHandler#invoke(java.lang.String, java.lang.String, javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse)
+     * @see org.ofbiz.webapp.event.EventHandler#invoke(ConfigXMLReader.Event, ConfigXMLReader.RequestMap, javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse)
      */
     public String invoke(Event event, RequestMap requestMap, HttpServletRequest request, HttpServletResponse response) throws EventHandlerException {
         // TODO: consider changing this to use the new UtilHttp.parseMultiFormData method

Modified: ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/SimpleEventHandler.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/SimpleEventHandler.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/SimpleEventHandler.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/SimpleEventHandler.java Sun May 29 11:02:09 2011
@@ -29,6 +29,7 @@ import org.ofbiz.base.util.UtilHttp;
 import org.ofbiz.base.util.UtilProperties;
 import org.ofbiz.minilang.MiniLangException;
 import org.ofbiz.minilang.SimpleMethod;
+import org.ofbiz.webapp.control.ConfigXMLReader;
 import org.ofbiz.webapp.control.ConfigXMLReader.Event;
 import org.ofbiz.webapp.control.ConfigXMLReader.RequestMap;
 
@@ -48,7 +49,7 @@ public class SimpleEventHandler implemen
     }
 
     /**
-     * @see org.ofbiz.webapp.event.EventHandler#invoke(Event, org.ofbiz.webapp.control.ConfigXMLReader.RequestMap, HttpServletRequest, HttpServletResponse)
+     * @see org.ofbiz.webapp.event.EventHandler#invoke(ConfigXMLReader.Event, ConfigXMLReader.RequestMap, javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse)
      */
     public String invoke(Event event, RequestMap requestMap, HttpServletRequest request, HttpServletResponse response) throws EventHandlerException {
         String xmlResource = event.path;

Modified: ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/WfsEventHandler.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/WfsEventHandler.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/WfsEventHandler.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/WfsEventHandler.java Sun May 29 11:02:09 2011
@@ -75,12 +75,12 @@ public class WfsEventHandler implements
     }
 
     /** Invoke the web event
-     *@param eventPath The path or location of this event
-     *@param eventMethod The method to invoke
-     *@param request The servlet request object
-     *@param response The servlet response object
-     *@return String Result code
-     *@throws EventHandlerException
+     * @param event Contains information about what to execute
+     * @param requestMap Contains information about the request-map the event was called from
+     * @param request The servlet request object
+     * @param response The servlet response object
+     * @return String Result code
+     * @throws EventHandlerException
      */
     public String invoke(Event event, RequestMap requestMap, HttpServletRequest request, HttpServletResponse response) throws EventHandlerException {
         //LocalDispatcher dispatcher = (LocalDispatcher) request.getAttribute("dispatcher");

Modified: ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/XmlRpcEventHandler.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/XmlRpcEventHandler.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/XmlRpcEventHandler.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/XmlRpcEventHandler.java Sun May 29 11:02:09 2011
@@ -57,6 +57,7 @@ import org.ofbiz.service.GenericServiceE
 import org.ofbiz.service.LocalDispatcher;
 import org.ofbiz.service.ModelService;
 import org.ofbiz.service.ServiceUtil;
+import org.ofbiz.webapp.control.ConfigXMLReader;
 import org.ofbiz.webapp.control.ConfigXMLReader.Event;
 import org.ofbiz.webapp.control.ConfigXMLReader.RequestMap;
 
@@ -89,7 +90,7 @@ public class XmlRpcEventHandler extends
     }
 
     /**
-     * @see org.ofbiz.webapp.event.EventHandler#invoke(Event, org.ofbiz.webapp.control.ConfigXMLReader.RequestMap, HttpServletRequest, HttpServletResponse)
+     * @see org.ofbiz.webapp.event.EventHandler#invoke(ConfigXMLReader.Event, ConfigXMLReader.RequestMap, javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse)
      */
     public String invoke(Event event, RequestMap requestMap, HttpServletRequest request, HttpServletResponse response) throws EventHandlerException {
         String report = request.getParameter("echo");

Modified: ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/ftl/OfbizContentTransform.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/ftl/OfbizContentTransform.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/ftl/OfbizContentTransform.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/ftl/OfbizContentTransform.java Sun May 29 11:02:09 2011
@@ -43,7 +43,8 @@ public class OfbizContentTransform imple
 
     public final static String module = OfbizContentTransform.class.getName();
 
-    private static String getArg(Map args, String key) {
+    @SuppressWarnings("unchecked")
+ private static String getArg(Map args, String key) {
         String  result = "";
         Object obj = args.get(key);
         if (obj != null) {
@@ -62,7 +63,8 @@ public class OfbizContentTransform imple
         return result;
     }
     
-    public Writer getWriter(final Writer out, Map args) {
+    @SuppressWarnings("unchecked")
+ public Writer getWriter(final Writer out, Map args) {
         final StringBuilder buf = new StringBuilder();
         final String imgSize = OfbizContentTransform.getArg(args, "variant");
         return new Writer(out) {

Modified: ofbiz/branches/jackrabbit20100709/framework/webtools/config/WebtoolsUiLabels.xml
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/webtools/config/WebtoolsUiLabels.xml?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/webtools/config/WebtoolsUiLabels.xml (original)
+++ ofbiz/branches/jackrabbit20100709/framework/webtools/config/WebtoolsUiLabels.xml Sun May 29 11:02:09 2011
@@ -1275,7 +1275,7 @@
         <value xml:lang="de">Entitäten - alphabetisch</value>
         <value xml:lang="en">Entities - Alphabetical</value>
         <value xml:lang="fr">Entités - Alphabétique</value>
-        <value xml:lang="it">Entità - Ordine alfabetico</value>
+        <value xml:lang="it">Entità in ordine alfabetico</value>
         <value xml:lang="pt">Entidades - por ordem alfabética</value>
         <value xml:lang="th">Entities - ที่เรียงตามลำดับอักษร</value>
         <value xml:lang="zh">实体 - 按字母顺序</value>

Modified: ofbiz/branches/jackrabbit20100709/framework/webtools/src/org/ofbiz/webtools/UtilCacheEvents.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/webtools/src/org/ofbiz/webtools/UtilCacheEvents.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/webtools/src/org/ofbiz/webtools/UtilCacheEvents.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/webtools/src/org/ofbiz/webtools/UtilCacheEvents.java Sun May 29 11:02:09 2011
@@ -40,7 +40,7 @@ public class UtilCacheEvents {
     /** An HTTP WebEvent handler the specified element from the specified cache
      * @param request The HTTP request object for the current JSP or Servlet request.
      * @param response The HTTP response object for the current JSP or Servlet request.
-     * @return
+     * @return return an HTTP WebEvent handler the specified element from the specified cache
      */
     public static String removeElementEvent(HttpServletRequest request, HttpServletResponse response) {
         String errMsg = "";
@@ -112,7 +112,7 @@ public class UtilCacheEvents {
     /** An HTTP WebEvent handler that clears the named cache
      * @param request The HTTP request object for the current JSP or Servlet request.
      * @param response The HTTP response object for the current JSP or Servlet request.
-     * @return
+     * @return return an HTTP WebEvent handler that clears the named cache
      */
     public static String clearEvent(HttpServletRequest request, HttpServletResponse response) {
         String errMsg = "";
@@ -149,7 +149,7 @@ public class UtilCacheEvents {
     /** An HTTP WebEvent handler that clears all caches
      * @param request The HTTP request object for the current JSP or Servlet request.
      * @param response The HTTP response object for the current JSP or Servlet request.
-     * @return
+     * @return return an HTTP WebEvent handler that clears all caches
      */
     public static String clearAllEvent(HttpServletRequest request, HttpServletResponse response) {
         String errMsg = "";
@@ -171,7 +171,7 @@ public class UtilCacheEvents {
     /** An HTTP WebEvent handler that updates the named cache
      * @param request The HTTP request object for the current JSP or Servlet request.
      * @param response The HTTP response object for the current JSP or Servlet request.
-     * @return
+     * @return return an HTTP WebEvent handler that updates the named cache
      */
     public static String updateEvent(HttpServletRequest request, HttpServletResponse response) {
         String errMsg = "";

Modified: ofbiz/branches/jackrabbit20100709/framework/webtools/src/org/ofbiz/webtools/WebToolsServices.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/webtools/src/org/ofbiz/webtools/WebToolsServices.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/webtools/src/org/ofbiz/webtools/WebToolsServices.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/webtools/src/org/ofbiz/webtools/WebToolsServices.java Sun May 29 11:02:09 2011
@@ -872,9 +872,9 @@ public class WebToolsServices {
 
     /** Performs an entity maintenance security check. Returns hasPermission=true
      * if the user has the ENTITY_MAINT permission.
-     * @param dctx
-     * @param context
-     * @return
+     * @param dctx the dispatch context
+     * @param context the context
+     * @return return the result of the service execution
      */
     public static Map<String, Object> entityMaintPermCheck(DispatchContext dctx, Map<String, ? extends Object> context) {
         GenericValue userLogin = (GenericValue) context.get("userLogin");

Modified: ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/datafile/viewdatafile.ftl
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/datafile/viewdatafile.ftl?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/datafile/viewdatafile.ftl (original)
+++ ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/datafile/viewdatafile.ftl Sun May 29 11:02:09 2011
@@ -16,15 +16,6 @@ KIND, either express or implied.  See th
 specific language governing permissions and limitations
 under the License.
 -->
-<div class="screenlet">
-  <div class="screenlet-title-bar">
-    <ul>
-      <li class="h3">${uiLabelMap.WebtoolsDataFileMainTitle}</li>
-    </ul>
-    <br class="clear"/>
-  </div>
-  <div class="screenlet-body">
-    <br />
     <p>${uiLabelMap.WebtoolsDataFileMessage1}.</p>
     <br />
     <#if security.hasPermission("DATAFILE_MAINT", session)>
@@ -159,5 +150,3 @@ under the License.
     <#else>
       <h3>You do not have permission to use this page (DATAFILE_MAINT needed)</h3>
     </#if>
-  </div>
-</div>

Modified: ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/entity/CheckDb.ftl
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/entity/CheckDb.ftl?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/entity/CheckDb.ftl (original)
+++ ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/entity/CheckDb.ftl Sun May 29 11:02:09 2011
@@ -16,7 +16,6 @@ KIND, either express or implied.  See th
 specific language governing permissions and limitations
 under the License.
 -->
-<div>
     <h3>${uiLabelMap.WebtoolsCheckUpdateDatabase}</h3>
     <form method="post" action="${encodeURLCheckDb}">
         <input type="hidden" name="option" value="checkupdatetables"/>
@@ -111,9 +110,8 @@ under the License.
         ${uiLabelMap.WebtoolsGroupName}: <input type="text" name="groupName" value="${groupName}" size="40"/>
         <input type="submit" value="${uiLabelMap.CommonUpdate}"/>
     </form>
-    <hr />
-</div>
 <#if miters?has_content>
+    <hr />
     <ul>
         <#list miters as miter>
             <li>${miter}</li>

Modified: ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/entity/EntityExportAll.ftl
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/entity/EntityExportAll.ftl?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/entity/EntityExportAll.ftl (original)
+++ ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/entity/EntityExportAll.ftl Sun May 29 11:02:09 2011
@@ -17,11 +17,8 @@ specific language governing permissions
 under the License.
 -->
 
-<h1>${uiLabelMap.WebtoolsExportFromDataSource}</h1>
-<br />
-<p>
-    ${uiLabelMap.WebtoolsXMLExportInfo}
-</p>
+<div class="page-title"><span>${uiLabelMap.WebtoolsExportFromDataSource}</span></div>
+<p>${uiLabelMap.WebtoolsXMLExportInfo}</p>
 <#if results?has_content>
     <hr />
     <h2>${uiLabelMap.WebtoolsResults}:</h2>
@@ -29,10 +26,7 @@ under the License.
         <p>${result}</p>
     </#list>
 </#if>
-
 <hr />
-
-<h2>${uiLabelMap.WebtoolsExport}:</h2>
 <form method="post" action="<@ofbizUrl>entityExportAll</@ofbizUrl>">
     ${uiLabelMap.WebtoolsOutputDirectory}: <input type="text" size="60" name="outpath" value="${outpath?if_exists}" /><br />
     ${uiLabelMap.WebtoolsTimeoutSeconds}: <input type="text" size="6" value="${txTimeout?default('7200')}" name="txTimeout"/><br />

Modified: ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/entity/EntityImport.ftl
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/entity/EntityImport.ftl?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/entity/EntityImport.ftl (original)
+++ ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/entity/EntityImport.ftl Sun May 29 11:02:09 2011
@@ -17,12 +17,9 @@ specific language governing permissions
 under the License.
 -->
 
-<h1>${uiLabelMap.WebtoolsImportToDataSource}</h1>
-<br />
+<div class="page-title"><span>${uiLabelMap.WebtoolsImportToDataSource}</span></div>
 <p>${uiLabelMap.WebtoolsXMLImportInfo}</p>
 <hr />
-<h2>${uiLabelMap.WebtoolsImport}:</h2>
-<br />
 
   <form method="post" action="<@ofbizUrl>entityImport</@ofbizUrl>">
     ${uiLabelMap.WebtoolsAbsoluteFileNameOrUrl}:<br />

Modified: ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/entity/EntityImportDir.ftl
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/entity/EntityImportDir.ftl?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/entity/EntityImportDir.ftl (original)
+++ ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/entity/EntityImportDir.ftl Sun May 29 11:02:09 2011
@@ -17,11 +17,9 @@ specific language governing permissions
 under the License.
 -->
 
-<h1>${uiLabelMap.WebtoolsImportToDataSource}</h1>
-<br />
+<div class="page-title"><span>${uiLabelMap.WebtoolsImportToDataSource}</span></div>
 <p>${uiLabelMap.WebtoolsXMLImportInfo}</p>
 <hr />
-<h2>${uiLabelMap.WebtoolsImport}:</h2>
 
   <form method="post" action="<@ofbizUrl>entityImportDir</@ofbizUrl>">
     ${uiLabelMap.WebtoolsAbsolutePath}:<br />

Modified: ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/entity/EntityImportReaders.ftl
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/entity/EntityImportReaders.ftl?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/entity/EntityImportReaders.ftl (original)
+++ ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/entity/EntityImportReaders.ftl Sun May 29 11:02:09 2011
@@ -17,12 +17,9 @@ specific language governing permissions
 under the License.
 -->
 
-<h1>${uiLabelMap.WebtoolsImportToDataSource}</h1>
-<br />
+<div class="page-title"><span>${uiLabelMap.WebtoolsImportToDataSource}</span></div>
 <p>${uiLabelMap.WebtoolsXMLImportInfo}</p>
 <hr />
-  <h2>${uiLabelMap.WebtoolsImport}:</h2>
-
   <form method="post" action="<@ofbizUrl>entityImportReaders</@ofbizUrl>">
     Enter Readers (comma separated, no spaces; from entityengine.xml and ofbiz-component.xml files; common ones include seed,ext,demo):<br />
     <input type="text" size="60" name="readers" value="${readers?default("seed")}"/><br />

Modified: ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/entity/EntityMaint.ftl
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/entity/EntityMaint.ftl?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/entity/EntityMaint.ftl (original)
+++ ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/entity/EntityMaint.ftl Sun May 29 11:02:09 2011
@@ -16,14 +16,6 @@ KIND, either express or implied.  See th
 specific language governing permissions and limitations
 under the License.
 -->
-<div class="screenlet">
-  <div class="screenlet-title-bar">
-    <ul>
-      <li class="h3">${uiLabelMap.WebtoolsEntityDataMaintenance}</li>
-    </ul>
-    <br class="clear"/>
-  </div>
-  <div class="screenlet-body">
     <div>
        <form action="<@ofbizUrl>/entitymaint</@ofbizUrl>">
           <b>${uiLabelMap.CommonGroup}:</b>
@@ -35,29 +27,21 @@ under the License.
           </select>
           <b>${uiLabelMap.WebtoolsEntityName}:</b>
           <input type= "text" name= "filterByEntityName" value="${parameters.filterByEntityName?if_exists}"/>
-          <input type="submit"/>
+          <input type="submit" value="${uiLabelMap.CommonApply}"/>
        </form>
     </div>
-    <p><b><u>${uiLabelMap.CommonNote}</u></b></p>
-    <p>
-       <b>${uiLabelMap.WebtoolsCreate}</b> = ${uiLabelMap.CommonCreateNew}&nbsp;&nbsp;
-       <b>${uiLabelMap.WebtoolsReln}</b> = ${uiLabelMap.WebtoolsViewRelations}&nbsp;&nbsp;
-       <b>${uiLabelMap.WebtoolsFind}</b> = ${uiLabelMap.WebtoolsFindRecord}&nbsp;&nbsp;
-       <b>${uiLabelMap.WebtoolsAll}</b> = ${uiLabelMap.WebtoolsFindAllRecords}&nbsp;&nbsp;
-    </p>
-    <br />
     <#assign firstChar = "x">
     <#assign anchor="">
     <#assign alt_row = false>
     <#assign right_col = false>
-
-    <#list entitiesList as entity>
+    <div class="button-bar">
+      <#list entitiesList as entity>
         <#if entity.entityName?substring(0, 1) != firstChar>
-            <#assign firstChar = entity.entityName?substring(0, 1)>
-            <a href="#Entity_${firstChar}">${firstChar}</a>&nbsp;
+          <#assign firstChar = entity.entityName?substring(0, 1)>
+          <a href="#Entity_${firstChar}">${firstChar}</a>&nbsp;
         </#if>
-    </#list>
-    <br /><br />
+      </#list>
+    </div>
     <div class="screenlet">
       <div class="screenlet-title-bar">
         <ul>
@@ -103,12 +87,12 @@ under the License.
                 </#if>
               <#else>
                 <#if entity.entityPermissionCreate == 'Y'>
-                  <a href='<@ofbizUrl>ViewGeneric?entityName=${entity.entityName}</@ofbizUrl>'>${uiLabelMap.WebtoolsCreate}</a>
+                  <a href='<@ofbizUrl>ViewGeneric?entityName=${entity.entityName}</@ofbizUrl>' title='${uiLabelMap.CommonCreateNew}'>${uiLabelMap.WebtoolsCreate}</a>
                 </#if>
                 <#if entity.entityPermissionView == 'Y'>
-                  <a href='<@ofbizUrl>ViewRelations?entityName=${entity.entityName}</@ofbizUrl>'>${uiLabelMap.WebtoolsReln}</a>
-                  <a href='<@ofbizUrl>FindGeneric?entityName=${entity.entityName}</@ofbizUrl>'>${uiLabelMap.WebtoolsFind}</a>
-                  <a href='<@ofbizUrl>FindGeneric?entityName=${entity.entityName}&amp;find=true&amp;VIEW_SIZE=50&amp;VIEW_INDEX=0</@ofbizUrl>'>${uiLabelMap.WebtoolsAll}</a>
+                  <a href='<@ofbizUrl>ViewRelations?entityName=${entity.entityName}</@ofbizUrl>' title='${uiLabelMap.WebtoolsViewRelations}'>${uiLabelMap.WebtoolsReln}</a>
+                  <a href='<@ofbizUrl>FindGeneric?entityName=${entity.entityName}</@ofbizUrl>' title='${uiLabelMap.WebtoolsFindRecord}'>${uiLabelMap.WebtoolsFind}</a>
+                  <a href='<@ofbizUrl>FindGeneric?entityName=${entity.entityName}&amp;find=true&amp;VIEW_SIZE=50&amp;VIEW_INDEX=0</@ofbizUrl>' title='${uiLabelMap.WebtoolsFindAllRecords}'>${uiLabelMap.WebtoolsAll}</a>
                 </#if>
               </#if>
             </td>
@@ -124,5 +108,3 @@ under the License.
         </table>
       </div>
     </div>
-  </div>
-</div>

Modified: ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/entity/EntitySQLProcessor.ftl
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/entity/EntitySQLProcessor.ftl?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/entity/EntitySQLProcessor.ftl (original)
+++ ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/entity/EntitySQLProcessor.ftl Sun May 29 11:02:09 2011
@@ -16,14 +16,6 @@ KIND, either express or implied.  See th
 specific language governing permissions and limitations
 under the License.
 -->
-<div class="screenlet">
-  <div class="screenlet-title-bar">
-    <ul>
-      <li class="h3">${uiLabelMap.WebtoolsSqlProcessor}</li>
-    </ul>
-    <br class="clear"/>
-  </div>
-  <div class="screenlet-body">
     <form method="post" action="EntitySQLProcessor" name="EntitySQLCommand">
       <table class="basic-table" cellspacing="0">
         <tr>
@@ -62,8 +54,7 @@ under the License.
         </tr>
       </table>
     </form>
-  </div>
-</div>
+
 <div class="screenlet">
   <div class="screenlet-title-bar">
     <ul>

Modified: ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/entity/xmldsdump.ftl
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/entity/xmldsdump.ftl?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/entity/xmldsdump.ftl (original)
+++ ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/entity/xmldsdump.ftl Sun May 29 11:02:09 2011
@@ -35,8 +35,7 @@ under the License.
   </div>
 </#macro>
 
-<h1>${uiLabelMap.PageTitleEntityExport}</h1>
-<br />
+<div class="page-title"><span>${uiLabelMap.PageTitleEntityExport}</span></div>
 <p>${uiLabelMap.WebtoolsXMLExportInfo}</p>
 <hr />
 

Modified: ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/service/availableservices.ftl
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/service/availableservices.ftl?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/service/availableservices.ftl (original)
+++ ofbiz/branches/jackrabbit20100709/framework/webtools/webapp/webtools/service/availableservices.ftl Sun May 29 11:02:09 2011
@@ -363,14 +363,11 @@ under the License.
         </#if>
       </div>
     </form>
-    <br />
   </#if>
 
   <div class="screenlet">
-    <div class="screenlet-title-bar">
-      <h3>${uiLabelMap.WebtoolsServicesListFor} ${dispatcherName?default(uiLabelMap.CommonNA)} (${servicesFoundCount} ${uiLabelMap.CommonFound})</h3>
-    </div>
     <div class="screenlet-body">
+      <label>${uiLabelMap.WebtoolsServicesListFor} ${dispatcherName?default(uiLabelMap.CommonNA)} (${servicesFoundCount} ${uiLabelMap.CommonFound})</label>
       <table class="basic-table hover-bar" cellspacing='0'>
         <tr class="header-row">
           <td>${uiLabelMap.WebtoolsServiceName}</td>

Modified: ofbiz/branches/jackrabbit20100709/framework/webtools/widget/CacheScreens.xml
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/webtools/widget/CacheScreens.xml?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/webtools/widget/CacheScreens.xml (original)
+++ ofbiz/branches/jackrabbit20100709/framework/webtools/widget/CacheScreens.xml Sun May 29 11:02:09 2011
@@ -36,7 +36,7 @@ under the License.
                                 <if-has-permission permission="UTIL_CACHE" action="_VIEW"/>
                             </condition>
                             <widgets>
-                                <screenlet title="${uiLabelMap.PageTitleFindUtilCache}">
+                                <screenlet>
                                     <label>${uiLabelMap.WebtoolsMemory} ${uiLabelMap.WebtoolsTotalMemory} ${memory} ${uiLabelMap.WebtoolsFreeMemory} ${freeMemory} ${uiLabelMap.WebtoolsUsedMemory} ${usedMemory}
                                         ${uiLabelMap.WebtoolsMaxMemory} ${maxMemory}</label>
                                     <include-menu name="FindCache" location="component://webtools/widget/Menus.xml"/>
--- ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/ServiceEventHandler.java (original)
+++ ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/ServiceEventHandler.java Sun May 29 11:02:09 2011
@@ -53,6 +53,7 @@ import org.ofbiz.service.ModelParam;
 import org.ofbiz.service.ModelService;
 import org.ofbiz.service.ServiceAuthException;
 import org.ofbiz.service.ServiceValidationException;
+import org.ofbiz.webapp.control.ConfigXMLReader;
 import org.ofbiz.webapp.control.ConfigXMLReader.Event;
 import org.ofbiz.webapp.control.ConfigXMLReader.RequestMap;
 
@@ -73,7 +74,7 @@ public class ServiceEventHandler impleme
     }
 
     /**
* @see org.ofbiz.webapp.event.EventHandler#invoke(java.lang.String, java.lang.String, javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse)
      */
     public String invoke(Event event, RequestMap requestMap, HttpServletRequest request, HttpServletResponse response) throws EventHandlerException {
         // make sure we have a valid reference to the Service Engine
@@ -73,7 +74,7 @@ public class ServiceEventHandler impleme
 
     /**
-     * @see org.ofbiz.webapp.event.EventHandler#invoke(java.lang.String, java.lang.String, javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse)
+     * @see org.ofbiz.webapp.event.EventHandler#invoke(ConfigXMLReader.Event, ConfigXMLReader.RequestMap, javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse)
      */
     public String invoke(Event event, RequestMap requestMap, HttpServletRequest request, HttpServletResponse response) throws EventHandlerException {

Modified: ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/ServiceMultiEventHandler.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/webapp/src/org/ofbiz/webapp/event/ServiceMultiEventHandler.java?rev=1128865&r1=1128864&r2=1128865&view=diff
==============================================================================